"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = require("chalk");
const build_1 = require("@ionic/cli-utils/lib/build");
const command_1 = require("@ionic/cli-utils/lib/command");
const errors_1 = require("@ionic/cli-utils/lib/errors");
class BuildCommand extends command_1.Command {
    getRunner() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (!this.runner) {
                this.runner = yield build_1.BuildRunner.createFromProject(this.env, this.env.project);
            }
            return this.runner;
        });
    }
    getMetadata() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const options = [];
            const exampleCommands = [''];
            let description = `${chalk_1.default.green('ionic build')} will perform an Ionic build, which compiles web assets and prepares them for deployment.`;
            let groups = [];
            try {
                const runner = yield this.getRunner();
                const libmetadata = yield runner.getCommandMetadata();
                groups = libmetadata.groups || [];
                options.push(...libmetadata.options || []);
                description += libmetadata.description ? `\n\n${libmetadata.description.trim()}` : '';
                exampleCommands.push(...libmetadata.exampleCommands || []);
            }
            catch (e) {
                if (!(e instanceof errors_1.RunnerNotFoundException)) {
                    throw e;
                }
            }
            options.push(...build_1.COMMON_BUILD_COMMAND_OPTIONS);
            return {
                name: 'build',
                type: 'project',
                summary: 'Build web assets and prepare your app for any platform targets',
                description,
                groups,
                exampleCommands,
                options,
            };
        });
    }
    preRun(inputs, options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (inputs.length > 0 && ['android', 'ios', 'wp8', 'windows', 'browser'].includes(inputs[0])) {
                this.env.log.warn(`${chalk_1.default.green('ionic build')} is for building web assets and takes no arguments. See ${chalk_1.default.green('ionic build --help')}.\n` +
                    `Ignoring argument ${chalk_1.default.green(inputs[0])}. Perhaps you meant ${chalk_1.default.green('ionic cordova build ' + inputs[0])}?\n`);
                inputs.splice(0);
            }
        });
    }
    run(inputs, options, runinfo) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { build } = yield Promise.resolve().then(() => require('@ionic/cli-utils/lib/build'));
            yield build(this.env, inputs, options);
        });
    }
}
exports.BuildCommand = BuildCommand;
