"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const chalk_1 = require("chalk");
const format_1 = require("@ionic/cli-framework/utils/format");
const command_1 = require("@ionic/cli-utils/lib/command");
const integrations_1 = require("@ionic/cli-utils/lib/integrations");
class IntegrationsListCommand extends command_1.Command {
    getMetadata() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            return {
                name: 'list',
                type: 'project',
                summary: 'List available and active integrations in your app',
            };
        });
    }
    run(inputs, options) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const projectConfig = yield this.env.project.load();
            const integrations = yield Promise.all(integrations_1.INTEGRATION_NAMES.map((name) => tslib_1.__awaiter(this, void 0, void 0, function* () { return this.env.project.createIntegration(name); })));
            const status = (name) => {
                const c = projectConfig.integrations[name];
                if (c) {
                    if (c.enabled === false) {
                        return chalk_1.default.dim.red('disabled');
                    }
                    return chalk_1.default.green('enabled');
                }
                return chalk_1.default.dim('not added');
            };
            this.env.log.rawmsg(format_1.columnar(integrations.map(i => [chalk_1.default.bold(i.name), i.summary, status(i.name)]), { headers: ['name', 'summary', 'status'] }));
        });
    }
}
exports.IntegrationsListCommand = IntegrationsListCommand;
